darkhistory.spec.spectools.EnglossRebinData — DarkHistory documentation

# darkhistory.spec.spectools.EnglossRebinData

class `darkhistory.spec.spectools.` `EnglossRebinData`(in_eng, engloss_arr, final_eng)

  Structure for energy loss rebinning data.

  Parameters: | in_eng : ndarray The injected energy. engloss_arr : ndarray Energy loss abscissa (second dimension of grid_vals) final_eng : ndarray The final energy abscissa to bin into.

  Notes

  This class is used to store data for energy loss rebinning that only depends on the abscissae specified.

  Attributes: | in_eng : ndarray The injected energy. engloss_arr : ndarray Energy loss abscissa (second dimension of grid_vals) final_eng : ndarray The final energy abscissa to bin into. new_eng : ndarray final_eng, but with additional first bin for underflow. bin_ind : 2D ndarray The (fractional) bin indices of final_eng that the data will be assigned to. ind_low : slice Slice which should have some part assigned to underflow. ind_reg : slice Slice which should have some part rebinned in the grid. reg_bin_low : ndarray Index of lower energy bins of the grid that particles should be assigned to. reg_bin_upp : ndarray Index of higher energy bins of the grid that particles should be assigned to. low_bin_low : ndarray Marks grid points that have some component assigned to underflow. in_eng_mask : ndarray in_eng index of every point on the grid.

  Methods

  rebin |

  `__init__`(in_eng, engloss_arr, final_eng)

    Initialize self. See help(type(self)) for accurate signature.

  Methods

  `__init__`(in_eng, engloss_arr, final_eng) | Initialize self.
  `rebin`(grid_vals) |

#### Previous topic

darkhistory.spec.spectools.rebin_N_arr

#### Next topic

darkhistory.spec.spectra

### This Page

Show Source